@@ -8,7 +8,8 @@ from .misc import (concat_list, is_list_of, is_seq_of, is_tuple_of, iter_cast,
                    list_cast, slice_list, swap_element, to_dict_of_list,
                    to_list_of_dict, tuple_cast)
 from .path import (abs_path, base_name, dir_exist, dir_name, file_exist, join,
-                   mkdir, pure_ext, pure_name, remove, split_ext, symlink)
+                   mkdir, pure_ext, pure_name, remove, rename, split_ext,
+                   symlink)
 from .progress import ProgressBar
 from .registry import Registry, build_object
 from .timer import Timer
@@ -20,6 +21,6 @@ __all__ = [
     'iter_cast', 'list_cast', 'slice_list', 'swap_element', 'to_dict_of_list',
     'to_list_of_dict', 'tuple_cast', 'abs_path', 'base_name', 'dir_exist',
     'dir_name', 'file_exist', 'join', 'mkdir', 'pure_ext', 'pure_name',
-    'remove', 'split_ext', 'symlink', 'ProgressBar', 'Registry',
+    'remove', 'rename', 'split_ext', 'symlink', 'ProgressBar', 'Registry',
     'build_object', 'Timer'
 ]
